@@ -2,7 +2,7 @@
 
 """
 Directory : mistool
-Name      : latexUse
+Name      : latex_use
 Version   : 2012.09
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
@@ -78,7 +78,7 @@ This method simply eases the raising of some specific errors.
 
 CHAR_TO_ESCAPE = {
     'text': "{}_$&%#",
-    'math': "{}_$&%#" 
+    'math': "{}_$&%#"
 }
 
 CHAR_TO_LATEXIFY = {
@@ -334,7 +334,7 @@ ALL_EXT_TO_CLEAN = [
     '4ct', '4tc', 'idv', 'lg', 'tmp', 'xref',
 # slide
 #
-# 
+#
     'nav', 'snm', 'vrb',
 # editor
 #
@@ -343,13 +343,13 @@ ALL_EXT_TO_CLEAN = [
     'synctex.gz', 'synctex.gz(busy)',
 # float
 #
-# 
+#
     'fff', 'ttt',
 # list
 #
 # ``bcl`` is produced by the package ``bclogo`` : this gives the list of
 # the logos.
-# 
+#
 # ``f`` is for Figure, ``l`` for Listing (cf. the package ``listings``),
 # and ``t`` for Table.
     'lof', 'lol', 'lot', 'bcl',
@@ -361,10 +361,10 @@ ALL_EXT_TO_CLEAN = [
 #
 # ``out`` is produced by the package ``hyperref`` with the option
 # ``bookmarks``, and ``brf`` with the option ``backref``.
-# 
+#
 # The package `` glossary`` produces ``glo`` and ``gls``, and also ``ist``
 # if an additional makeindex compilation is launched.
-# 
+#
 # ``idx`` and ``ind`` are produced by makeindex compilations.
     'aux', 'brf', 'out', 'glo', 'ist', 'gls', 'idx', 'ind',
 # biblio
@@ -374,15 +374,15 @@ ALL_EXT_TO_CLEAN = [
     'bbl', 'run.xml',
 # theorem
 #
-# 
+#
     'thm',
 # eledmac
 #
-# 
+#
     '¨number',
 # eledpar
 #
-# 
+#
     'R¨number'
 ]
 
