@@ -2,7 +2,7 @@
 
 """
 Directory : mistool
-Name      : logTestUse
+Name      : log_test_use
 Version   : 2013.09
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
