@@ -2,7 +2,7 @@
 
 """
 Directory : mistool
-Name      : osUse
+Name      : os_use
 Version   : 2013.09
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
@@ -935,21 +935,43 @@ This function uses the following variables.
     ``(-1)`` indicates that there is no maximum.
 
     The default value is ``0`` which asks to only look for in the direct content
-    of the main directory to analyse.
+    of the main directory to analyse. In other word, ``depth = 0`` asks to find
+    the directories directly contained in the main directory analysed.
     """
-    firstDir = True
+    if depth == -1:
+        subDepth = - 1
 
-    for onePath in os_use.nextFile(
-        main    = main,
-        ext     = None,
-        depth   = -1,
-        keepDir = "all"
-    ):
-        if firstDir:
-            firstDir = False
+    else:
+        if depth == 0:
+            subDepth = None
 
         else:
-            yield onePath
+            subDepth = depth - 1
+
+        depth   += 1
+
+    for pathDir in os.listdir(main):
+        pathDir = main + SEP + pathDir
+
+        if isDir(pathDir) \
+        and __isSubDepthGood(
+            main  = main,
+            sub   = pathDir,
+            depth = depth
+        ):
+            yield pathDir
+
+            if subDepth != None:
+                for subPathDir in nextDir(
+                    pathDir,
+                    depth = subDepth
+                ):
+                    if __isSubDepthGood(
+                        main  = main,
+                        sub   = subPathDir,
+                        depth = depth
+                    ):
+                        yield subPathDir
 
 def listDir(*args, **kwargs):
     """
