@@ -2,7 +2,7 @@
 
 """
 Directory : mistool
-Name      : pythonUse
+Name      : python_use
 Version   : 2013.04
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
