@@ -2,8 +2,8 @@
 
 """
 Directory : mistool
-Name      : stringUse
-Version   : 2013.07
+Name      : string_use
+Version   : 2013.09
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
 
@@ -56,11 +56,11 @@ python::
     from mistool import string_use
 
     littleExample = string_use.replace(
-            text        = "One, two, three,..."
+            text        = "one, two, three,..."
             replacement = {
-                'One'  : "1",
-                'Two'  : "2",
-                'Three': "3"
+                'one'  : "1",
+                'two'  : "2",
+                'three': "3"
             }
         )
     )
@@ -1205,9 +1205,11 @@ This function uses the following variables.
     return (text[:s], text[e:])
 
 
-# ---------------------------------- #
-# -- PLAYING WITH CASE OF LETTERS -- #
-# ---------------------------------- #
+# --------------------- #
+# -- CASE FORMATTING -- #
+# --------------------- #
+
+__CASE_VARIANTS = ['lower', 'upper', 'sentence', 'title', 'firstLast']
 
 def case(
     text,
@@ -1222,18 +1224,18 @@ This function produces different case variants of the text contained in the
 string variable ``text``.
 
 
-For example, ``case("OnE eXamPLe", "lower")``, ``case("OnE eXamPLe", "upper")``
-and ``case("OnE eXamPLe", "sentence")`` and ``case("One example", "title")`` are
+For example, ``case("onE eXamPLe", "lower")``, ``case("onE eXamPLe", "upper")``
+and ``case("onE eXamPLe", "sentence")`` and ``case("onE example", "title")`` are
 respectively equal to "one example", "ONE EXAMPLE", "OnE eXamPLe" and "One
 Example".
 
 
-You can alos the weird transformation ``case("OnE eXamPLe", "firstLast")`` which
+You can also the weird transformation ``case("onE eXamPLe", "firstLast")`` which
 is equal to "One examplE". This special feature is indeed used by pyBaNaMa which
 is another project of the author of the package ¨mistool.
 
 
-If you need all the possible case variants, juste use  ``case("OnE eXamPLe",
+If you need all the possible case variants, juste use ``case("onE eXamPLe",
 "all")`` which is equal to the following dictionary.
 
 python::
@@ -1284,7 +1286,7 @@ This function uses the following variables.
 
     if kind == 'all':
         answer = {}
-        for kind in ['lower', 'upper', 'sentence', 'title', 'firstLast']:
+        for kind in __CASE_VARIANTS:
             answer[kind] = case(text, kind)
         return answer
 
@@ -1322,7 +1324,8 @@ This function uses the following variables.
 
     else:
         raise StringUseError(
-            '<< {0} >> is not an existing kind of case variant.'.format(kind)
+            '<< {0} >> is not an existing kind of case variant formatting.' \
+                .format(kind)
         )
 
 def camelTo(
@@ -1372,6 +1375,56 @@ This function uses the following variables.
     return newLines
 
 
+# ------------------ #
+# -- CASE TESTING -- #
+# ------------------ #
+
+def isCase(
+    text,
+    kind
+):
+    """
+-----------------
+Small description
+-----------------
+
+If ``kind`` is one of the strings ``"lower"``, ``"upper"``, ``"sentence"``,
+``"title"`` and ``"firstLast"`` the function will simply return the result of
+the test ``text == case(text, kind)``. See the documentation of the function
+``case`` for more informations about this case formats.
+
+If ``kind = "mix"``, the answer returned will be ``True`` only if the text is
+not all lower, not all upper and not in sentence case format.
+
+warning::
+    Something like ``One_examplE`` is both in mix and sentence case formats.
+
+
+-------------
+The arguments
+-------------
+
+This function uses the following variables.
+
+    1) ``text`` is simply a string representing the text to be tested.
+
+    2) ``kind`` is a string whose values can only be ``"lower"``, ``"upper"``,
+    ``"sentence"`` or ``"mix"``.
+    """
+    if kind == "mix":
+        return text != text.lower() \
+        and text != text.upper() \
+        and text != case(text, "sentence")
+
+    elif kind not in __CASE_VARIANTS:
+        raise StringUseError(
+            '<< {0} >> is not an existing kind of case variant testing.' \
+                .format(kind)
+        )
+
+    return text == case(text, kind)
+
+
 # ------------------- #
 # -- SHORTEN LINES -- #
 # ------------------- #
