@@ -2,7 +2,7 @@
 
 """
 Directory : mistool
-Name      : urlUse
+Name      : url_use
 Version   : 2012.08
 Author    : Christophe BAL
 Mail      : projetmbc@gmail.com
